import { ComponentClass } from 'react';
import Taro, { Component } from '@tarojs/taro';
import { View } from '@tarojs/components';

import './Vcode.scss';

type PageOwnProps = {
  text?: string;
};
type PageState = {
  defaultText: string;
  counting: boolean;
  count: number;
  timer: number | null;
};

interface Vcode {
  props: PageOwnProps;
  state: PageState;
}

class Vcode extends Component {
  static externalClasses = ['vcode-classname'];

  constructor(props: PageOwnProps) {
    super(props);
    this.state = {
      defaultText: props.text ? props.text : '获取验证码',
      counting: false,
      count: 10,
      timer: null,
    };
  }

  componentWillUnmount() {
    const { timer } = this.state;
    if (timer) {
      clearTimeout(timer);
    }
  }

  countStart() {
    this.setState({
      counting: true,
    });
    this.countDown();
  }

  countDown() {
    const { count } = this.state;
    if (count == 1) {
      this.setState({
        counting: false,
      });
    } else {
      const timer = setTimeout(() => {
        this.countDown();
      }, 1000);
      this.setState({
        count: count - 1,
        timer: timer,
      });
    }
  }

  render() {
    const { defaultText, counting, count } = this.state;
    return counting ? (
      <View className='vcode-classname Vcode Counting'>{`${count}S`}</View>
    ) : (
      <View className='vcode-classname Vcode' onClick={this.countStart}>
        {defaultText}
      </View>
    );
  }
}

export default Vcode as ComponentClass<PageOwnProps, PageState>;
