import { ComponentClass } from 'react';
import Taro, { Component, Config } from '@tarojs/taro';
import { connect } from '@tarojs/redux';

import { View, Text, Input, Image } from '@tarojs/components';
import SearchIcon from '../../images/login/icon_search@2x.png';
import { Campus, CampusList } from '../../types/Campus/Campus';

import { fetchAllCampus } from '../../api/login';
import { StoreState, updateUserInfo } from '../../store/rootReducers/userinfo';
import User from 'src/types/User/User';

const resData = [
  {
    id: 47,
    schoolId: 36,
    name: '保定职业技术学院1',
    mobile: '15212121222',
    address: '河北省保定市新市区朝阳南大街613号',
    introduce: '',
    fd_version: '1',
    isDel: 0,
    openLattice: 'N',
    firstPin: 'B',
  },
  {
    id: 126,
    schoolId: 36,
    name: '保定职业技术学院测试学院1',
    mobile: '15232569878',
    address: '敖德萨所大所多',
    introduce: '奥术大师多',
    fd_version: '2',
    isDel: 0,
    openLattice: 'N',
    firstPin: 'B',
  },
  {
    id: 12,
    schoolId: 6,
    name: '成师温江校区',
    mobile: '13608207722',
    address: '海科路东段99号',
    introduce: '',
    fd_version: '1',
    isDel: 0,
    openLattice: 'N',
    firstPin: 'C',
  },
  {
    id: 116,
    schoolId: 200004,
    name: '成都正阳1.0校区 ',
    mobile: '15881097999',
    address: '四川省成都市温江区',
    introduce: '用于虚拟客户体验使用',
    fd_version: '1',
    isDel: 0,
    openLattice: 'N',
    firstPin: 'C',
  },
];

type PageStateProps = {
  userinfo: StoreState;
};
type PageDispatchProps = {
  updateUserInfo: (e: User) => void;
};

type PageState = {
  campusList: CampusList;
  filterList: CampusList;
  filterName: string;
};

type IProps = PageStateProps & PageDispatchProps;
interface SelectCampus {
  props: IProps;
  state: PageState;
}

@connect(
  ({ userinfo }) => ({
    userinfo,
  }),
  dispatch => ({
    updateUserInfo(entity: User) {
      dispatch(updateUserInfo(entity));
    },
  }),
)
class SelectCampus extends Component {
  config: Config = {
    navigationBarTitleText: '检索学校',
  };

  constructor(props: IProps) {
    super(props);
    this.state = {
      filterName: '',
      campusList: [],
      filterList: [],
    };
  }

  componentWillMount() {
    fetchAllCampus()
      .then(res => {
        console.log(res);
        let campusIndexArr: Array<string> = [];
        let campusList: CampusList = [];
        res.data.map((campus: Campus) => {
          let firstPin = campus.firstPin;
          if (firstPin) {
            let index = campusIndexArr.indexOf(firstPin);
            if (index > -1) {
              campusList[index].children.push(campus);
            } else {
              campusIndexArr.push(firstPin);
              campusList.push({
                firstPin: firstPin,
                children: [campus],
              });
            }
          }
        });
        this.setState({
          campusList: campusList,
          filterList: campusList,
        });
      })
      .catch(err => {
        console.log(err);
        let campusIndexArr: Array<string> = [];
        let campusList: CampusList = [];
        resData.map((campus: Campus) => {
          let firstPin = campus.firstPin;
          if (firstPin) {
            let index = campusIndexArr.indexOf(firstPin);
            if (index > -1) {
              campusList[index].children.push(campus);
            } else {
              campusIndexArr.push(firstPin);
              campusList.push({
                firstPin: firstPin,
                children: [campus],
              });
            }
          }
        });
        this.setState({
          campusList: campusList,
          filterList: campusList,
        });
      });
    this.setState(({ campusList }: PageState) => ({
      filterList: campusList,
    }));
  }
  searchList() {
    let { filterName, campusList } = this.state;
    if (filterName) {
      const filterList = campusList.reduce(
        (totalArr: CampusList, campusItem) => {
          let arr = campusItem.children.filter(
            i => i.name.indexOf(filterName) > -1,
          );
          if (arr.length > 0) {
            totalArr.push({
              firstPin: campusItem.firstPin,
              children: arr,
            });
          }
          return totalArr;
        },
        [],
      );
      this.setState({
        filterList: filterList,
      });
    } else {
      this.setState({
        filterList: campusList,
      });
    }
  }
  bindCampus({ id, name, schoolId }: Campus) {
    this.props.updateUserInfo({
      campusId: id,
      campusName: name,
      schoolId: schoolId,
    });
    Taro.navigateBack();
  }

  render() {
    const { filterList, filterName } = this.state;
    return (
      <View className='Location topBr'>
        <View className='searchBox'>
          <Input
            className='br8 searchInput'
            value={filterName}
            onInput={({ detail: { value } }) =>
              this.setState({
                filterName: value.trim(),
              })
            }
            type='text'
            placeholder='请输入学校名称'
          />
          <View className='searchBtn' onClick={this.searchList}>
            <Image className='searchIcon' src={SearchIcon} />
            <Text>搜索</Text>
          </View>
        </View>
        <View className='locationList'>
          {filterList.map(campusItem => (
            <View key={campusItem.firstPin} className='locationArea'>
              <View id={campusItem.firstPin} className='locationTitle'>
                {campusItem.firstPin}
              </View>
              {campusItem.children.map((campus, index) => (
                <View
                  key={index}
                  className='locationItem'
                  onClick={() => this.bindCampus(campus)}>
                  {campus.name}
                </View>
              ))}
            </View>
          ))}
        </View>
      </View>
    );
  }
}

export default SelectCampus as ComponentClass;
